<?php
/*****************************************************************************
 * ManageAssets.php
 * Contains the asset management controller.
 *
 * Kabuki CMS (C) 2013-2017, Aaron van Geffen
 *****************************************************************************/

class ManageAssets extends HTMLController
{
	public function __construct()
	{
		// Ensure it's just admins at this point.
		if (!Registry::get('user')->isAdmin())
			throw new NotAllowedException();

		Session::resetSessionToken();

		$options = [
			'columns' => [
				'id_asset' => [
					'value' => 'id_asset',
					'header' => 'ID',
					'is_sortable' => true,
				],
				'subdir' => [
					'value' => 'subdir',
					'header' => 'Subdirectory',
					'is_sortable' => true,
				],
				'filename' => [
					'value' => 'filename',
					'header' => 'Filename',
					'is_sortable' => true,
					'parse' => [
						'type' => 'value',
						'link' => BASEURL . '/editasset/?id={ID_ASSET}',
						'data' => 'filename',
					],
				],
				'id_user_uploaded' => [
					'header' => 'User uploaded',
					'is_sortable' => true,
					'parse' => [
						'type' => 'function',
						'data' => function($row) {
							if (!empty($row['first_name']))
								return $row['first_name'] . ' ' . $row['surname'];
							else
								return 'n/a';
						},
					],
				],
				'dimensions' => [
					'header' => 'Dimensions',
					'is_sortable' => false,
					'parse' => [
						'type' => 'function',
						'data' => function($row) {
							if (!empty($row['image_width']))
								return $row['image_width'] . ' x ' . $row['image_height'];
							else
								return 'n/a';
						},
					],
				],
			],
			'start' => !empty($_GET['start']) ? (int) $_GET['start'] : 0,
			'sort_order' => !empty($_GET['order']) ? $_GET['order'] : '',
			'sort_direction' => !empty($_GET['dir']) ? $_GET['dir'] : '',
			'title' => 'Manage assets',
			'no_items_label' => 'No assets meet the requirements of the current filter.',
			'items_per_page' => 30,
			'base_url' => BASEURL . '/manageassets/',
			'get_data' => function($offset = 0, $limit = 30, $order = '', $direction = 'down') {
				if (!in_array($order, ['id_asset', 'id_user_uploaded', 'title', 'subdir', 'filename']))
					$order = 'id_asset';

				$data = Registry::get('db')->queryAssocs('
					SELECT a.id_asset, a.subdir, a.filename,
						a.image_width, a.image_height,
						u.id_user, u.first_name, u.surname
					FROM assets AS a
					LEFT JOIN users AS u ON a.id_user_uploaded = u.id_user
					ORDER BY {raw:order}
					LIMIT {int:offset}, {int:limit}',
					[
						'order' => $order . ($direction == 'up' ? ' ASC' : ' DESC'),
						'offset' => $offset,
						'limit' => $limit,
					]);

				return [
					'rows' => $data,
					'order' => $order,
					'direction' => $direction,
				];
			},
			'get_count' => 'Asset::getCount',
		];

		$table = new GenericTable($options);
		parent::__construct('Asset management - Page ' . $table->getCurrentPage() .'');
		$this->page->adopt(new TabularData($table));
	}
}
